==> sandium-6.x-1.3.tar.gz: sandium/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.2 2009/12/07 10:47:43 sunn Exp $
?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
<head>
<?php print $head ?>
<title><?php print $head_title ?></title>
<?php print $styles ?>
<?php print $scripts ?>
</head>
  <body>
    <div id="container">
      <div id="header">
        <div id="site-info">
          <div id="site-title"><h1><a href="<?php print base_path() ?>"><?php print $site_name; ?></a></h1></div>
          <div id="slogan"><?php print $site_slogan; ?></div>
        </div>
        <div id="search-box"><?php print $search_box; ?><img class="catch-me" src="<?php print base_path() . path_to_theme() ?>/images/search.png" /></div>
      </div>
      
      <div id="nav">
          <?php if (!empty($primary_links)): ?>
              <?php print theme('links', $primary_links, array('class' => 'links primary-links')); ?>
          <?php endif; ?>
      </div>
      
      <div id="content-wrapper">
        <div id="slash"><img src="<?php print base_path() . path_to_theme() ?>/images/photo.png" /></div>
        <div class="clear"></div>
        <?php if ($top_left || $top_middle || $top_right): ?>
        <div id="content-top">
          <div id="top-left"><?php print $top_left ?></div>
          <div id="top-middle"><?php print $top_middle ?></div>
          <div id="top-right"><?php print $top_right ?></div>
          <div class="clear"></div>
        </div>
        <?php endif; ?>
        <div class="clear"></div>

        <div id="content-bottom">
          <div id="leftside">
            <?php print $leftside ?>
            <div class="tabs"><?php print $tabs ?></div>
            <div class="tabs2"><?php print $tabs2 ?></div>
            <?php print $content ?>
          </div>
          <div id="rightside">
            <?php print $rightside ?>
          </div>
          <div class="clear"></div>
        </div>

        <?php if ($bottom_left || $bottom_middle || $bottom_right): ?>
        <div id="content-verybottom">
          <div id="bottom-left"><?php print $bottom_left ?></div>
          <div id="bottom-middle"><?php print $bottom_middle ?></div>
          <div id="bottom-right"><?php print $bottom_right ?></div>
        </div>
        <div class="clear"></div>
        <?php endif; ?>
      </div><!-- end of content-wrapper -->
          <div id="footer">
            <?php if ($footer_left || $footer_right): ?>
            <div id="footer-left"><?php print $footer_left ?></div>
            <div class="fasel"></div>
            <div id="footer-right"><?php print $footer_right ?></div>
            <div class="clear"></div>
            <?php endif; ?>
            <div class="footer-message"><?php print $footer_message ?></div>
          </div>
    </div><!-- end of container -->
  </body>
</html>

==> sandium-6.x-1.6.tar.gz: sandium/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.3 2009/12/08 14:11:42 sunn Exp $
?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
<head>
<?php print $head ?>
<title><?php print $head_title ?></title>
<?php print $styles ?>
<?php print $scripts ?>
</head>
  <body>
    <div id="container">
      <div id="header">
        <div id="site-info">
          <div id="site-title"><h1><a href="<?php print base_path() ?>"><?php print $site_name; ?></a></h1></div>
          <div id="slogan"><?php print $site_slogan; ?></div>
        </div>
        <div id="search-box"><?php print $search_box; ?><img class="catch-me" src="<?php print base_path() . path_to_theme() ?>/images/search.png" /></div>
      </div>
      
      <div id="nav">
          <?php if (!empty($primary_links)): ?>
              <?php print theme('links', $primary_links, array('class' => 'links primary-links')); ?>
          <?php endif; ?>
      </div>
      
      <div id="content-wrapper">
        <div id="slash"><img src="<?php print base_path() . path_to_theme() ?>/images/photo.png" /></div>
        <div class="clear"></div>
        <?php if ($top_left || $top_middle || $top_right): ?>
        <div id="content-top">
          <div id="top-left" class="<?php print $body_classes; ?>"><?php print $top_left ?></div>
          <div id="top-middle" class="<?php print $body_classes; ?>"><?php print $top_middle ?></div>
          <div id="top-right" class="<?php print $body_classes; ?>"><?php print $top_right ?></div>
          <div class="clear"></div>
        </div>
        <?php endif; ?>
        <div class="clear"></div>

        <div id="content-bottom">
          <div id="leftside">
            <?php print $leftside ?>
            <div class="tabs"><?php print $tabs ?></div>
            <div class="tabs2"><?php print $tabs2 ?></div>
            <?php print $content ?>
          </div>
          <div id="rightside">
            <?php print $rightside ?>
          </div>
          <div class="clear"></div>
        </div>

        <div id="content-verybottom">
          <?php if($bottom_left): ?><div id="bottom-left" class="class="<?php print $body_classes; ?>""><?php print $bottom_left ?></div><?php endif; ?>
          <?php if($bottom_middle): ?><div id="bottom-middle" class="<?php print $body_classes; ?>"><?php print $bottom_middle ?></div><?php endif; ?>
          <?php if($bottom_right): ?><div id="bottom-right" class="<?php print $body_classes; ?>"><?php print $bottom_right ?></div><?php endif; ?>
        </div>
        <div class="clear"></div>
        
      </div><!-- end of content-wrapper -->
          <div id="footer">
            <?php if ($footer_left || $footer_right): ?>
            <div id="footer-left"><?php print $footer_left ?></div>
            <div class="fasel"></div>
            <div id="footer-right"><?php print $footer_right ?></div>
            <div class="clear"></div>
            <?php endif; ?>
            <div class="footer-message"><?php print $footer_message ?></div>
          </div>
    </div><!-- end of container -->
    <?php print $closure ?>
  </body>
</html>
